@@ -3,7 +3,7 @@
 ##############################################################################
 ##
 ##  Canon Inkjet Printer Driver for Linux
-##  Copyright CANON INC. 2001-2016
+##  Copyright CANON INC. 2001-2018
 ##
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
@@ -20,11 +20,11 @@
 ##
 ##############################################################################
 
-C_version="5.40-1"
-C_copyright_end="2016"
+C_version="5.70-1"
+C_copyright_end="2018"
 C_default_system="deb"
 
-P_support_printer=("MB2100" "MB2700" "IB4100" "MB5100" "MB5400" "TS9000" "TS8000" "TS6000" "TS5000" "MG3000" "E470" "G4000")
+P_support_printer=("TS8200" "XK80" "TS8230" "TS8280" "TS6200" "TS6230" "TS6280" "TS9500" "TR9530" "TS9580" "TR4500" "E4200")
 
 L_INST_COM_01_01="Command executed = %s\n"
 
